Struct polkadot_statement_table::generic::Config
source · pub struct Config {
pub allow_multiple_seconded: bool,
}Expand description
Table configuration.
Fields
allow_multiple_seconded: boolWhen this is true, the table will allow multiple seconded candidates per authority. This flag means that higher-level code is responsible for bounding the number of candidates.